@@ -198,4 +198,7 @@ CLI_MESSAGES = {
     'TryHelp': "Try the command with '-h' / '--help' option for more details.",
     'InvalidFileFormat': "Invalid file, not conforming to the expected '{0}' format.",
     'EnteredSecretValuesNotMatched': "Entered values for the secret did not macth.",
+    'RenderPathNotReleative': "Render path '{0}' is not releative to the application root directory.",
+    # 'InvalidRenderPath': "'{0}' is not a valid render path.",
+    'InvalidRenderPathExistingDir': "'{0}' is not a valid render path because it is an existing directory.",
 }
